==> ehome-rcm-0.9.0.tgz: package/es/loadable/index.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React, { PureComponent, Component } from 'react';
import Loadable from 'react-loadable'; // import { Toast } from 'antd-mobile';

var LoadableLoading =
/*#__PURE__*/
function (_ref) {
  _inherits(LoadableLoading, _ref);

  function LoadableLoading() {
    var _getPrototypeOf2;

    var _this;

    _classCallCheck(this, LoadableLoading);

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _possibleConstructorReturn(this, (_getPrototypeOf2 = _getPrototypeOf(LoadableLoading)).call.apply(_getPrototypeOf2, [this].concat(args)));

    _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "state", {});

    return _this;
  }

  _createClass(LoadableLoading, [{
    key: "componentDidMount",
    value: function componentDidMount() {
      if (document.getElementById('eh-loading') !== null && document.getElementById('eh-loading')) {
        // 加载资源时，index.html会有个默认的loading
        document.body.removeChild(document.getElementById('eh-loading'));
      }
    }
  }, {
    key: "render",
    value: function render() {
      return React.createElement("div", null);
    }
  }]);

  return LoadableLoading;
}(PureComponent || Component);
/**
 * reactLoadable
 * 对 react-loadable 的封装
 * @param {func} loader 加载组件的函数
 * @param {func} loading 加载 loading 组件的函数
 * @param {object} config react-loadable 所支持的配置项
 * */


function Loading(props) {
  console.log(props);
  console.log(props.error);

  if (props.error) {
    window.alert('加载失败,请刷新重试');
  } else if (props.timedOut) {
    window.alert('网络超时,请刷新重试');
  }

  return React.createElement(LoadableLoading, null);
}

var ReactLoadable = function ReactLoadable(loader) {
  var loading = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : Loading;
  var config = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};

  var pConfig = _extends({
    loader: loader,
    loading: loading,
    delay: 300
  }, config);

  return Loadable(pConfig);
};

export default ReactLoadable;

==> ehome-rcm-0.12.3.tgz: package/es/loadable/index.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React, { PureComponent, Component } from 'react';
import Loadable from 'react-loadable'; // import { Toast } from 'antd-mobile';

var LoadableLoading =
/*#__PURE__*/
function (_ref) {
  _inherits(LoadableLoading, _ref);

  function LoadableLoading() {
    var _getPrototypeOf2;

    var _this;

    _classCallCheck(this, LoadableLoading);

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _possibleConstructorReturn(this, (_getPrototypeOf2 = _getPrototypeOf(LoadableLoading)).call.apply(_getPrototypeOf2, [this].concat(args)));

    _defineProperty(_assertThisInitialized(_this), "state", {});

    return _this;
  }

  _createClass(LoadableLoading, [{
    key: "componentDidMount",
    value: function componentDidMount() {
      if (document.getElementById('eh-loading') !== null && document.getElementById('eh-loading')) {
        // 加载资源时，index.html会有个默认的loading
        document.body.removeChild(document.getElementById('eh-loading'));
      }
    }
  }, {
    key: "render",
    value: function render() {
      return React.createElement("div", null);
    }
  }]);

  return LoadableLoading;
}(PureComponent || Component);
/**
 * reactLoadable
 * 对 react-loadable 的封装
 * @param {func} loader 加载组件的函数
 * @param {func} loading 加载 loading 组件的函数
 * @param {object} config react-loadable 所支持的配置项
 * */


function Loading(props) {
  console.log(props);
  console.log(props.error);

  if (props.error) {
    window.alert('加载失败,请刷新重试');
  } else if (props.timedOut) {
    window.alert('网络超时,请刷新重试');
  }

  return React.createElement(LoadableLoading, null);
}

var ReactLoadable = function ReactLoadable(loader) {
  var loading = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : Loading;
  var config = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};

  var pConfig = _extends({
    loader: loader,
    loading: loading,
    delay: 300
  }, config);

  return Loadable(pConfig);
};

export default ReactLoadable;
